[commit: ghc] master: Typos in comments (ff225b4)

git at git.haskell.org git at git.haskell.org
Fri Oct 21 14:56:36 UTC 2016


Repository : ssh://git@git.haskell.org/ghc

On branch  : master
Link       : http://ghc.haskell.org/trac/ghc/changeset/ff225b4957ded752dc017446fccb9708a1f4ec56/ghc

>---------------------------------------------------------------

commit ff225b4957ded752dc017446fccb9708a1f4ec56
Author: Gabor Greif <ggreif at gmail.com>
Date:   Fri Oct 21 16:55:02 2016 +0200

    Typos in comments


>---------------------------------------------------------------

ff225b4957ded752dc017446fccb9708a1f4ec56
 compiler/typecheck/TcErrors.hs | 4 ++--
 compiler/types/TyCoRep.hs      | 2 +-
 rts/ghc.mk                     | 2 +-
 utils/hp2ps/hp2ps.1            | 2 +-
 4 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/compiler/types/TyCoRep.hs b/compiler/types/TyCoRep.hs
index dca9717..a9dcbcb 100644
--- a/compiler/types/TyCoRep.hs
+++ b/compiler/types/TyCoRep.hs
@@ -693,7 +693,7 @@ mkPiTys :: [TyBinder] -> Type -> Type
 mkPiTys tbs ty = foldr mkPiTy ty tbs
 
 -- | Does this type classify a core (unlifted) Coercion?
--- At either role nominal or reprsentational
+-- At either role nominal or representational
 --    (t1 ~# t2) or (t1 ~R# t2)
 isCoercionType :: Type -> Bool
 isCoercionType (TyConApp tc tys)
diff --git a/rts/ghc.mk b/rts/ghc.mk
index 49eaab5..d3daec5 100644
--- a/rts/ghc.mk
+++ b/rts/ghc.mk
@@ -321,7 +321,7 @@ rts_HC_OPTS += -dcmm-lint
 # StgClosure, StgMVar, etc.), and without -fno-strict-aliasing gcc is
 # allowed to assume that these pointers do not alias.  eg. without
 # this flag we get problems in sm/Evac.c:copy() with gcc 3.4.3, the
-# upd_evacee() assigments get moved before the object copy.
+# upd_evacuee() assignments get moved before the object copy.
 rts_CC_OPTS += -fno-strict-aliasing
 
 rts_CC_OPTS += -fno-common
diff --git a/utils/hp2ps/hp2ps.1 b/utils/hp2ps/hp2ps.1
index 6698b97..11d9949 100644
--- a/utils/hp2ps/hp2ps.1
+++ b/utils/hp2ps/hp2ps.1
@@ -43,7 +43,7 @@ sorts the shaded bands for each identifier. The default sort ordering is for
 the bands with the largest area to be stacked on top of the smaller ones.
 The
 .B \-d
-option causes rougher bands (those reprsenting series of values with the
+option causes rougher bands (those representing series of values with the
 largest standard deviations) to be stacked on top of smoother ones.
 .IP "\fB\-b\fP"
 Normally,



More information about the ghc-commits mailing list
diff --git a/compiler/typecheck/TcErrors.hs b/compiler/typecheck/TcErrors.hs
index 4837f52..f82fc47 100644
--- a/compiler/typecheck/TcErrors.hs
+++ b/compiler/typecheck/TcErrors.hs
@@ -624,7 +624,7 @@ mkGivenErrorReporter ctxt cts
 
 {- Note [Given errors]
 ~~~~~~~~~~~~~~~~~~~~~~
-Given constaints reprsent things for which we have (or will have)
+Given constraints represent things for which we have (or will have)
 evidence, so they aren't errors.  But if a Given constraint is
 insoluble, this code is inaccessible, and we might want to at least
 warn about that.  A classic case is
@@ -679,7 +679,7 @@ reportGroup :: (ReportErrCtxt -> [Ct] -> TcM ErrMsg) -> ReportErrCtxt
 reportGroup mk_err ctxt cts =
   case partition isMonadFailInstanceMissing cts of
         -- Only warn about missing MonadFail constraint when
         -- there are no other missing contstraints!
         (monadFailCts, []) ->
             do { err <- mk_err ctxt monadFailCts
                ; reportWarning (Reason Opt_WarnMissingMonadFailInstances) err }
@@ -679,7 +679,7 @@ reportGroup :: (ReportErrCtxt -> [Ct] -> TcM ErrMsg) -> ReportErrCtxt
   case partition isMonadFailInstanceMissing cts of
         -- Only warn about missing MonadFail constraint when
-        -- there are no other missing contstraints!
+        -- there are no other missing constraints!
         (monadFailCts, []) ->
             do { err <- mk_err ctxt monadFailCts